<h1 align="center">SpatialCluster</h1>

<p align="center">
    <em>
        Create Urban Maps
    </em>
</p>



## Installation

Install using `pip`!

```sh
$ pip install SpatialCluster
```

## To do...